'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validate = exports.load = undefined;

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _jsYaml = require('js-yaml');

var _jsYaml2 = _interopRequireDefault(_jsYaml);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var load = exports.load = function load(filename) {
  return _jsYaml2.default.safeLoad(_fs2.default.readFileSync(filename, 'utf-8'));
};

var validate = exports.validate = function validate(configuration) {
  var env = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'dev';

  if (!configuration.requires) throw new Error('Missing "requires" section in config (leave blank if not needed)');

  if (!configuration.mimetypes) throw new Error('Missing "mimetypes" section in config');

  if (!configuration.default || !Array.isArray(configuration.default)) throw new Error('Missing default tasks');

  if (!configuration.replacementPaths || !Array.isArray(configuration.replacementPaths)) throw new Error('Missing replacementPaths');

  (0, _keys2.default)(configuration.mimetypes).forEach(function (key) {
    if (!configuration.mimetypes[key][env]) throw new Error('Missing environment definition "' + env + '" in "' + key + '" mimetype');

    if (!configuration.mimetypes[key][env].tasks) throw new Error('Missing task list definition in "' + env + '" -> "' + key + '" mimetype (it can be empty array but must be defined)');

    if (!configuration.mimetypes[key][env].outputFolder) throw new Error('Missing outputFolder in "' + env + '" -> "' + key + '" mimetype');

    configuration.mimetypes[key][env].tasks.forEach(function (task) {
      if (!task.name) throw new Error('Invalid task definition in "' + env + '" -> "' + key + '" mimetype - the structure must be like this {name: coffee, args: { bare: true }}');

      if (!configuration.requires[task.name.split('.').shift()]) throw new Error('Undefined task "' + task.name + '" in "' + env + '" -> "' + key + '" mimetype, please include it in the "requires" section');
    });
  });
};